--- a/include/autoconf.hin
+++ b/include/autoconf.hin
@@ -1003,4 +1003,8 @@ Added missing headers after gettext upda
  */
 #	undef USE_ZLIB
 
+/* debian-specific */
+#define XFACE_ABLE
+#define NNTP_SERVER_FILE "/etc/news/server"
+
 #endif /* !TIN_AUTOCONF_H */
